import { CLOUD_SERVICE_PROVIDER_LIST, DEFAULT_CLOUD_CONTEXTS } from 'constant/others/other';
import useDrupalJsonApi from 'hooks/drupal_jsonapi';
import CloudContext from 'model/CloudContext';
import CloudServiceProvider from 'model/CloudServiceProvider';
import { createContext, useEffect, useState } from 'react';
import { useTranslation } from 'react-i18next';

type Action = {
  type: 'setLanguage',
  message: string
};

interface AppState {
  cloudContextList: CloudContext[];
  loadingFlg: boolean;
  dispatch: (action: Action) => void;
}

export const useAppState = (): AppState => {
  const { getEntityListAll } = useDrupalJsonApi();
  const [cloudContextList, setCloudContextList] = useState<CloudContext[]>([...DEFAULT_CLOUD_CONTEXTS]);
  const [loadingFlg, setLoadingFlg] = useState(true);
  const { i18n } = useTranslation();

  useEffect(() => {
    const languageName = window.localStorage.getItem('languageName');
    if (languageName !== null) {
      i18n.changeLanguage(languageName);
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);

  // Set cloud context list.
  useEffect(() => {
    const init = async () => {
      let newCloudContextList = [...DEFAULT_CLOUD_CONTEXTS];
      for (const cloudServiceProvider of CLOUD_SERVICE_PROVIDER_LIST) {
        try {
          const data = (await getEntityListAll('cloud_config', {}, cloudServiceProvider))
            .map((record: any) => {
              return {
                cloudServiceProvider: cloudServiceProvider as CloudServiceProvider,
                name: record.attributes.cloud_context,
                labelName: record.attributes.name
              };
            });
          newCloudContextList = [...newCloudContextList, ...data];
        } catch {
          // pass
        }
      }
      setCloudContextList(newCloudContextList);
      setLoadingFlg(false);
    };
    init();
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);

  const dispatch = (action: Action) => {
    switch (action.type) {
      case 'setLanguage':
        i18n.changeLanguage(action.message);
        window.localStorage.setItem('languageName', action.message);
        break;
    }
  };

  return {
    cloudContextList,
    loadingFlg,
    dispatch
  };
};

export const AppContext = createContext<AppState>({
  cloudContextList: [],
  loadingFlg: true,
  dispatch: () => { }
});
