<?php

namespace Drupal\cloud\Controller;

use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;

/**
 * {@inheritdoc}
 */
interface ApiControllerInterface {

  /**
   * Operate OpenStack entity.
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   HTTP request.
   * @param string $cloud_service_provider
   *   The cloud service provider.
   * @param string $cloud_context
   *   The cloud context.
   * @param string $entity_type_id
   *   The entity type ID.
   * @param string $entity_id
   *   The entity ID.
   * @param string $command
   *   Operation command.
   *
   * @return \Symfony\Component\HttpFoundation\JsonResponse
   *   The JSON response.
   */
  public function operateEntity(Request $request, string $cloud_service_provider, string $cloud_context, string $entity_type_id, string $entity_id, string $command): JsonResponse;

  /**
   * Get select options of image.
   *
   * @param string $cloud_service_provider
   *   The cloud service provider.
   * @param string $cloud_context
   *   The cloud context.
   *
   * @return \Symfony\Component\HttpFoundation\JsonResponse
   *   The JSON response.
   */
  public function getImageOptions($cloud_service_provider, $cloud_context): JsonResponse;

  /**
   * Get select options of security groups.
   *
   * @param string $cloud_service_provider
   *   The cloud context.
   * @param string $cloud_context
   *   The cloud context.
   * @param string $subnet_id
   *   The subnet ID.
   *
   * @return \Symfony\Component\HttpFoundation\JsonResponse
   *   The JSON response.
   */
  public function getSecurityGroupOptions($cloud_service_provider, $cloud_context, $subnet_id = ''): JsonResponse;

  /**
   * Get select options of key pair.
   *
   * @param string $cloud_service_provider
   *   The cloud service provider.
   * @param string $cloud_context
   *   The cloud context.
   *
   * @return \Symfony\Component\HttpFoundation\JsonResponse
   *   The JSON response.
   */
  public function getKeyPairOptions($cloud_service_provider, $cloud_context): JsonResponse;

  /**
   * Get select options of network.
   *
   * @param string $cloud_service_provider
   *   The cloud service provider.
   * @param string $cloud_context
   *   The cloud context.
   *
   * @return \Symfony\Component\HttpFoundation\JsonResponse
   *   The JSON response.
   */
  public function getNetworkOptions($cloud_service_provider, $cloud_context): JsonResponse;

}
